# 🤖 Corby

⚡ Create your AI applications from zero to deploy in minutes ⚡

![pypi](https://github.com/JoseHervas/corby/actions/workflows/publish.yml/badge.svg) ![pylint](https://github.com/JoseHervas/corby/actions/workflows/pylint.yml/badge.svg) [![Python 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-360/) [![Downloads](https://static.pepy.tech/badge/corby)](https://pepy.tech/project/corby) [![License: GPL-3](https://img.shields.io/badge/License-GPL3-green.svg)](https://opensource.org/licenses/GPL-3)

## 🚀 Quick Install

```bash
pip install corby
alias corby="python -m corby"
```

## 🤔 What is this?

AI applications are awesome, but... who has time to go through all the settings, configurations and the hell of folder structuring? 😫

**Corby** is a tool that bootstraps the skeleton of your AI applications so you don't have spend a ton of time preparing the configurations.

🚀 Just run the command `corby` on your terminal and get your AI application working in less than 1 minute!

## 📚 How to use

[📌 User guides can be found here 📌](docs)

```bash
usage: corby new {chatbot | notebook} [options]

positional arguments:
  {new}               Action to perform
  {chatbot,notebook}  Entity to work with

options:
  -h, --help          show this help message and exit
  -v, --version       Show version
  -d, --debug         Debug mode
```

## 🤝 Contribute

This project is open-source and therefore every contribution is more than welcome, whether it be in the form of a new feature, improved infrastructure, or better documentation.
